<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package ECD
 */

if ( ! function_exists( 'ecd_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function ecd_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( 'c' ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
			/* translators: the date the post was published */
			esc_html_x( 'Posted on %s', 'post date', 'ecd' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);

		$byline = sprintf(
			/* translators: the post author */
			esc_html_x( 'by %s', 'post author', 'ecd' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);

		echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

	}
endif;

if ( ! function_exists( 'ecd_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function ecd_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'ecd' ) );
			if ( $categories_list && ecd_categorized_blog() ) {
				/* translators: the post category */
				printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'ecd' ) . '</span>', $categories_list ); // WPCS: XSS OK.
			}

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html__( ', ', 'ecd' ) );
			if ( $tags_list ) {
				/* translators: the post tags */
				printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'ecd' ) . '</span>', $tags_list ); // WPCS: XSS OK.
			}
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link( esc_html__( 'Leave a comment', 'ecd' ), esc_html__( '1 Comment', 'ecd' ), esc_html__( '% Comments', 'ecd' ) );
			echo '</span>';
		}

		edit_post_link(
			sprintf(
				/* translators: %s: Name of current post */
				esc_html__( 'Edit %s', 'ecd' ),
				the_title( '<span class="screen-reader-text">"', '"</span>', false )
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

/**
 * Return SVG markup.
 *
 * @param  array  $args {
 *     Parameters needed to display an SVG.
 *
 * @param string $icon Required. Use the icon filename, e.g. "ecdebook-square".
 * @param string $title Optional. SVG title, e.g. "Facebook".
 * @param string $desc Optional. SVG description, e.g. "Share this post on Facebook".
 * }
 * @return string SVG markup.
 */
function ecd_get_svg( $args = array() ) {

	// Make sure $args are an array.
	if ( empty( $args ) ) {
		return esc_html__( 'Please define default parameters in the form of an array.', 'ecd' );
	}

	// Define an icon.
	if ( false === array_key_exists( 'icon', $args ) ) {
		return esc_html__( 'Please define an SVG icon filename.', 'ecd' );
	}

	// Set defaults.
	$defaults = array(
		'icon'  => '',
		'title' => '',
		'desc'  => '',
	);

	// Parse args.
	$args = wp_parse_args( $args, $defaults );

	// Figure out which title to use.
	$title = ( $args['title'] ) ? $args['title'] : $args['icon'];

	// Set aria hidden.
	$aria_hidden = ' aria-hidden="true"';

	// Set ARIA.
	$aria_labelledby = '';
	if ( $args['title'] && $args['desc'] ) {
		$aria_labelledby = ' aria-labelledby="title-ID desc-ID"';
		$aria_hidden = '';
	}

	// Begin SVG markup.
	$svg = '<svg class="icon icon-' . esc_attr( $args['icon'] ) . '"' . $aria_hidden . $aria_labelledby . ' role="img">';

	// Add title markup.
	$svg .= '<title>' . esc_html( $title ) . '</title>';

	// If there is a description, display it.
	if ( $args['desc'] ) {
		$svg .= '<desc>' . esc_html( $args['desc'] ) . '</desc>';
	}

	// Use absolute path in the Customizer so that icons show up in there.
	if ( is_customize_preview() ) {
		$svg .= '<use xlink:href="' . get_parent_theme_file_uri( '/assets/images/svg-icons.svg#icon-' . esc_html( $args['icon'] ) ) . '"></use>';
	} else {
		$svg .= '<use xlink:href="#icon-' . esc_html( $args['icon'] ) . '"></use>';
	}

	$svg .= '</svg>';

	return $svg;
}

/**
 * Trim the title length.
 *
 * @param array $args Parameters include length and more.
 * @return string        The shortened excerpt.
 */
function ecd_get_the_title( $args = array() ) {

	// Set defaults.
	$defaults = array(
		'length'  => 12,
		'more'    => '...',
	);

	// Parse args.
	$args = wp_parse_args( $args, $defaults );

	// Trim the title.
	return wp_trim_words( get_the_title( get_the_ID() ), $args['length'], $args['more'] );
}

/**
 * Limit the excerpt length.
 *
 * @param array $args Parameters include length and more.
 * @return string The shortened excerpt.
 */
function ecd_get_the_excerpt( $args = array() ) {

	// Set defaults.
	$defaults = array(
		'length' => 23,
		'more'   => '...',
	);

	// Parse args.
	$args = wp_parse_args( $args, $defaults );

	// Trim the excerpt.
	return wp_trim_words( get_the_excerpt(), absint( $args['length'] ), esc_html( $args['more'] ) );
}

/**
 * Echo an image, no matter what.
 *
 * @param string $size The image size to display. Default is thumbnail.
 */
function ecd_display_post_image( $size = 'thumbnail' ) {

	// If post has a featured image, display it.
	if ( has_post_thumbnail() ) {
		the_post_thumbnail( $size );
		return;
	}

	$attached_image_url = ecd_get_attached_image_url( $size );

	// Else, display an attached image or placeholder.
	?>
	<img src="<?php echo esc_url( $attached_image_url ); ?>" class="attachment-thumbnail wp-post-image" alt="<?php echo esc_html( get_the_title() ); ?>"/>
	<?php
}

/**
 * Return an image URL, no matter what.
 *
 * @param  string $size The image size to return. Deafault is thumbnail.
 * @return string       The image URL.
 */
function ecd_get_post_image_url( $size = 'thumbnail' ) {

	// If post has a featured image, return its URL.
	if ( has_post_thumbnail() ) {

		$featured_image_id = get_post_thumbnail_id( get_the_ID() );
		$media             = wp_get_attachment_image_src( $featured_image_id, $size );

		if ( is_array( $media ) ) {
			return current( $media );
		}
	}

	// Else, return the URL for an attached image or placeholder.
	return ecd_get_attached_image_url( $size );
}

/**
 * Get the URL of an image that's attached to the current post, else a placeholder image URL.
 *
 * @param  string $size The image size to return. Deafault is thumbnail.
 * @return string       The image URL.
 */
function ecd_get_attached_image_url( $size = 'thumbnail' ) {

	// Check for any attached image.
	$media = get_attached_media( 'image', get_the_ID() );
	$media = current( $media );

	// If an image is attached, return its URL.
	if ( is_array( $media ) && $media ) {
		return 'thumbnail' === $size ? wp_get_attachment_thumb_url( $media->ID ) : wp_get_attachment_url( $media->ID );
	}

	// Return URL to a placeholder image as a fallback.
	return get_stylesheet_directory_uri() . '/assets/images/placeholder.png';
}

/**
 * Echo the copyright text saved in the Customizer.
 */
function ecd_display_copyright_text() {

	// Grab our customizer settings.
	$copyright_text = get_theme_mod( 'ecd_copyright_text' );

	// Stop if there's nothing to display.
	if ( ! $copyright_text ) {
		return false;
	}

	// Return the text.
	echo '<span class="copyright-text">' . wp_kses_post( $copyright_text ) . '</span>';
}

/**
 * Display social sharing icons.
 */
function ecd_display_social_icons() {

	// Build the sharing URLs.
	$twitter_url  = 'https://twitter.com/share?text=' . rawurlencode( html_entity_decode( get_the_title() ) ) . '&amp;url=' . rawurlencode( get_the_permalink() );
	$ecdebook_url = 'https://www.ecdebook.com/sharer/sharer.php?u=' . rawurlencode( get_the_permalink() );
	$linkedin_url = 'https://www.linkedin.com/shareArticle?title=' . rawurlencode( html_entity_decode( get_the_title() ) ) . '&amp;url=' . rawurlencode( get_the_permalink() );

	?>
	<div class="social-share">
		<h5 class="social-share-title"><?php esc_html_e( 'Share This', 'ecd' ); ?></h5>
		<ul class="social-icons menu menu-horizontal">
			<li class="social-icon">
				<a href="<?php echo esc_url( $twitter_url ); ?>" onclick="window.open(this.href, 'targetwindow', 'toolbar=no, location=no, status=no, menubar=no, scrollbars=yes, resizable=yes, top=150, left=0, width=600, height=300' ); return false;">
					<?php echo ecd_get_svg( array( // WPCS: XSS ok.
						'icon'  => 'twitter-square',
						'title' => 'Twitter',
						'desc'  => esc_html__( 'Share on Twitter', 'ecd' ),
					) ); ?>
					<span class="screen-reader-text"><?php esc_html_e( 'Share on Twitter', 'ecd' ); ?></span>
				</a>
			</li>
			<li class="social-icon">
				<a href="<?php echo esc_url( $ecdebook_url ); ?>" onclick="window.open(this.href, 'targetwindow', 'toolbar=no, location=no, status=no, menubar=no, scrollbars=yes, resizable=yes, top=150, left=0, width=600, height=300' ); return false;">
					<?php echo ecd_get_svg( array( // WPCS: XSS ok.
						'icon'  => 'ecdebook-square',
						'title' => 'Facebook',
						'desc'  => esc_html__( 'Share on Facebook', 'ecd' ),
					) ); ?>
					<span class="screen-reader-text"><?php esc_html_e( 'Share on Facebook', 'ecd' ); ?></span>
				</a>
			</li>
			<li class="social-icon">
				<a href="<?php echo esc_url( $linkedin_url ); ?>" onclick="window.open(this.href, 'targetwindow', 'toolbar=no, location=no, status=no, menubar=no, scrollbars=yes, resizable=yes, top=150, left=0, width=475, height=505' ); return false;">
					<?php echo ecd_get_svg( array( // WPCS: XSS ok.
						'icon'  => 'linkedin-square',
						'title' => 'LinkedIn',
						'desc'  => esc_html__( 'Share on LinkedIn', 'ecd' ),
					) ); ?>
					<span class="screen-reader-text"><?php esc_html_e( 'Share on LinkedIn', 'ecd' ); ?></span>
				</a>
			</li>
		</ul>
	</div><!-- .social-share -->
	<?php
}

/**
 * Display the social links saved in the customizer.
 */
function ecd_display_social_network_links() {

	// Create an array of our social links for ease of setup.
	// Change the order of the networks in this array to change the output order.
	$social_networks = array( 'ecdebook', 'googleplus', 'instagram', 'linkedin', 'twitter' );

	?>
	<ul class="social-icons">
		<?php
		// Loop through our network array.
		foreach ( $social_networks as $network ) :

			// Look for the social network's URL.
			$network_url = get_theme_mod( 'ecd_' . $network . '_link' );

			// Only display the list item if a URL is set.
			if ( ! empty( $network_url ) ) : ?>
				<li class="social-icon <?php echo esc_attr( $network ); ?>">
					<a href="<?php echo esc_url( $network_url ); ?>">
						<?php echo ecd_get_svg( array( // WPCS: XSS ok.
							'icon'  => $network . '-square',
							'title' => /* translators: the social network name */ sprintf( esc_html_e( 'Link to %s', 'ecd' ), ucwords( esc_html( $network ) ) ),
						) ); ?>
						<span class="screen-reader-text"><?php echo /* translators: the social network name */ sprintf( esc_html_e( 'Link to %s', 'ecd' ), ucwords( esc_html( $network ) ) ); // WPCS: XSS ok. ?></span>
					</a>
				</li><!-- .social-icon -->
			<?php endif;
		endforeach; ?>
	</ul><!-- .social-icons -->
	<?php
}

/**
 * Pagination
 */
if ( ! function_exists( 'ecd_page_numbers_pagination' ) ) :

	function ecd_page_numbers_pagination() {

		global $wp_query, $wp_rewrite;

		$wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;

		$pagination = array(
			'base'      => @add_query_arg( 'paged', '%#%' ),
			'format'    => '',
			'total'     => $wp_query->max_num_pages,
			'current'   => $current,
			'type'      => 'list',
			'prev_next' => true,
			'prev_text' => __( '<svg xmlns="http://www.w3.org/2000/svg" width="11.121" height="19.414" viewBox="0 0 11.121 19.414"><path id="Stroke_1_Copy" data-name="Stroke 1 Copy" d="M0,0,9,9,0,18" transform="translate(10.414 18.707) rotate(-180)" fill="none" stroke="#979797" stroke-miterlimit="10" stroke-width="2"/></svg>', 'ecd' ),
			'next_text' => __( '<svg xmlns="http://www.w3.org/2000/svg" width="11.121" height="19.414" viewBox="0 0 11.121 19.414"><path id="Stroke_1" data-name="Stroke 1" d="M0,0,9,9,0,18" transform="translate(0.707 0.707)" fill="none" stroke="#979797" stroke-miterlimit="10" stroke-width="2"/></svg>', 'ecd' )
		);

		// if ( $wp_rewrite->using_permalinks() )
		// 	$pagination['base'] = user_trailingslashit( trailingslashit( remove_query_arg( 's', get_pagenum_link( 1 ) ) ) . 'page/%#%/', 'paged' );

		if ( ! empty( $wp_query->query_vars['s'] ) )
			$pagination['add_args'] = array( 's' => get_query_var( 's' ) );

		// Display pagination
		printf( '<nav class="navigation paging-navigation"><h1 class="screen-reader-text">%1$s</h1>%2$s</nav>',
			esc_html_x( 'Page navigation', '', 'ecd' ),
			paginate_links( $pagination )
		);
	}
endif;

/**
 * Post navigation
 */

if ( ! function_exists( 'ecd_posts_navigation' ) ) :

	function ecd_posts_navigation() {
		// Don't print empty markup if there's only one page.
		if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
			return;
		}
		?>
		<div class="infinite-navigation clearfix">
			<nav class="navigation posts-navigation" role="navigation">

				<div id="infinite-handle" class="nav-links">
					<?php if ( get_next_posts_link() ) : ?>
						<div class="nav-next">
							<?php next_posts_link( esc_html__( 'Load More', 'ecd' ) ); ?>
						</div>
					<?php endif; ?>
				</div><!-- .nav-links -->

			</nav><!-- .navigation -->
			<div id="loading-is"></div>
		</div>
		<?php
	}

endif;

/**
 * ACF Link
 */

if ( ! function_exists( 'acf_link' ) ) :

	function acf_link($link, $class, $image, $link_text ) {
		if ( $link ) :
			$link_url = $link['url'];
			$link_title = $link['title'];
			if ( $link_text != '' ) $link_title = $link_text;
			$link_target = ( $link['target'] != '' ) ? 'target="' . $link['target'] . '"' : '';
			
			$style = ( $image != '' ) ? 'style="background-image:url(' . wp_get_attachment_image_url( $image, 'full' ) . ')"' : '';
			echo '<a href="' . $link_url .'" class="' . $class . '"' . $link_target . ' ' . $style . '>' . $link_title . '</a>';
		endif;
	}

endif;

  /**
 * Displays Related Posts
 */
function ecd_related_post( $ID ) {

	$post_id        = get_the_ID();
	$posts_per_page = 1;
	$categories     = get_the_terms( $post_id, 'category' );
	$cats           = array();

	if ( ! empty( $categories ) ) {
		foreach ( $categories as $category ) {
			$cats[] = $category->term_id;
		}
		$cats = implode( ',', $cats );

		$args = array(
			'cat'            => $cats,
			'post_type'      => 'post',
			'post_status'    => 'publish',
			'posts_per_page' => $posts_per_page,
			'post__not_in'   => array( $post_id )
		);

		//Get related posts
		$related_query = new WP_Query( $args );

		if ( !$ID ) : 

			// Related post Loop
			if ( $related_query->have_posts() ) : ?>

				<?php while( $related_query->have_posts() ) : $related_query->the_post(); ?>
					<?php
						$link_url = get_the_permalink();
						$link_target = '';
						
						if ( get_field( 'link', get_the_ID() ) ) :
							$link = get_field( 'external_link', get_the_ID() );
							$link_url = $link['url'];
							$link_target = 'target="' . $link['target'] . '"';
						endif;
					?>
					<article class="related-post">
						<p><?php _e( 'Related Article', 'ecd' ); ?></p>
						<h2><a href="<?php echo $link_url; ?>" <?php echo $link_target; ?>><?php the_title(); ?><svg xmlns="http://www.w3.org/2000/svg" width="16" height="27" viewBox="0 0 16 27"><g><g transform="rotate(360 -1033.5 -1948.5)"><path fill="none" stroke="#002664" stroke-miterlimit="50" stroke-width="2" d="M1 26v0l13-12.5v0L1 1v0"/></g></g></svg></a></h2>
					</article>
				<?php endwhile; ?>

				<?php wp_reset_postdata(); ?>
			<?php endif;

		else : ?>
			<?php
				$link_url = get_the_permalink( $ID );
				$link_target = '';
				
				if ( get_field( 'link', $ID ) ) :
					$link = get_field( 'external_link', $ID );
					$link_url = $link['url'];
					$link_target = 'target="' . $link['target'] . '"';
				endif;
			?>
			<article class="related-post">
				<p><?php _e( 'Related Article', 'ecd' ); ?></p>
				<h2><a href="<?php echo $link_url; ?>" <?php echo $link_target; ?>><?php echo get_the_title($ID); ?><svg xmlns="http://www.w3.org/2000/svg" width="16" height="27" viewBox="0 0 16 27"><g><g transform="rotate(360 -1033.5 -1948.5)"><path fill="none" stroke="#002664" stroke-miterlimit="50" stroke-width="2" d="M1 26v0l13-12.5v0L1 1v0"/></g></g></svg></a></h2>
			</article>
		<?php endif;

	}
	else {
		return;
	}
}

// 132 Characters Excerpt
function custom_excerpt($string) {
	$string = strip_tags($string);
	if (strlen($string) > 132) {
		$stringCut = substr($string, 0, 132);
		$endPoint = strrpos($stringCut, ' ');
		$string = $endPoint? substr($stringCut, 0, $endPoint) : substr($stringCut, 0);
		$string .= '...';
	}
	echo $string;
}

/**
 * Get User Popup
 */
add_action('wp_ajax_staff_popup', 'staff_popup'); // wp_ajax_{action}
add_action('wp_ajax_nopriv_staff_popup', 'staff_popup'); // wp_ajax_nopriv_{action}
function staff_popup() {
	$memberID = $_POST['memberID'];
	$image = get_the_post_thumbnail( $memberID, 'staff' );
	$popup['image'] = $image;
	$name = get_the_title( $memberID );
	$popup['name'] = $name;
	$post = get_post($memberID); // specific post
	$bio = apply_filters('the_content', $post->post_content);
	$popup['bio'] = $bio;
	$title = get_field( 'title', $memberID );
	$popup['title'] = $title;
	$phone = get_field( 'contact', $memberID );
	$popup['phone'] = $phone;
	echo json_encode( $popup );
	die();
}

/**
 * Load More Events
 */
add_action('wp_ajax_load_more_events', 'load_more_events'); // wp_ajax_{action}
add_action('wp_ajax_nopriv_load_more_events', 'load_more_events'); // wp_ajax_nopriv_{action}
function load_more_events() {

	$currentPage = $_POST['currentPage'];
	$currentPage++;

	$args = array(
		'post_type'      =>      'event',
		'posts_per_page' =>      4,
		'order'          =>      'DESC',
		'orderby'        =>      'meta_value',
		'meta_key'       =>      'date',
		'meta_type'      =>      'DATE',
		'paged'			 =>		 $currentPage
		
	);
	$events = new WP_Query($args);
	while ( $events->have_posts() ) : $events->the_post(); ?>
		<?php
		$today = strtotime('today');
		$date_time = strtotime( get_field( 'date') );
		$date = date( 'F d, Y', $date_time );
		?>
		<?php echo ( $date_time < $today ) ? '<h2 class="past-events">Past Events</h2>' : ''; ?>

		<div class="event-wrap hide-event">
			<a class="inner-wrap" href="<?php echo $link; ?>">
				<div class="image"><?php the_post_thumbnail( 'event' ); ?></div>
				<div class="event-info">
					<p class="date"><?php echo $date; ?></p>
					<h3><?php the_title(); ?></h3>
					<?php the_content(); ?>
					<span class="read-more"><?php _e( 'See Highlights', 'ecd' ); ?></span>
				</div>
			</div>
		</div>
		<?php $counter++; ?>
	<?php endwhile;
	die();
}

/**
 * Redirect FAQ Archive to FAQ Page
 */
function archive_to_custom_archive() {
    if( is_post_type_archive( 'faqs' ) && !is_search() ) {
        wp_redirect( home_url( '/faq/' ), 301 );
        exit();
    }
}
add_action( 'template_redirect', 'archive_to_custom_archive' );